@@ -1,4 +1,4 @@
-from ctypes import c_void_p, c_char_p, POINTER
+from ctypes import POINTER, c_void_p, c_char_p
 
 from ..lib import lib
 
@@ -9,4 +9,4 @@ http_query_pairs_get_value.argtypes = [c_void_p, c_char_p]
 http_query_pairs_get_value.restype = POINTER (String)
 
 http_query_pairs_print = lib.http_query_pairs_print
-http_query_pairs_print.argtypes = [c_void_p]
\ No newline at end of file
+http_query_pairs_print.argtypes = [c_void_p]
